<?php
/**
 *   easycheckout : Easy checkout PRO for prestashop
 *
 *   @module     Easy checkout PRO (easycheckout)
 *   @file       OrderOpcController.php
 *   @subject    Sobreescribe la clase de PS
 *   @author    eraseunaventa.com
 *   @copyright Copyright (c) 2016 Erase Una Venta
 *   @license   Commercial license
 *   Support by mail: soporte@eraseunaventa.com
 */

class OrderOpcController extends OrderOpcControllerCore
{

    /**
     * Assign template vars related to page content
     *
     * @see FrontController::initContent()
     */
    public function initContent()
    {
        parent::initContent();
        $dir_templates = _PS_MODULE_DIR_ . '/easycheckout/views/templates/front/';
        if (version_compare(_PS_VERSION_, '1.6', '<')){
            $dir_templates = _PS_MODULE_DIR_ . '/easycheckout/views/templates/front15/';
        }
        $easycopro_campo_json = Configuration::get('EASYCOPRO_campo');
        $this->context->smarty->assign(array(
            'dir_templates_easy' => $dir_templates,
            'social_login' => Module::isEnabled('easysociallogin'),
            'EASYCOPRO_campo' => Tools::jsonDecode($easycopro_campo_json, true),
            'error' => empty($this->error) ? array() : $this->error,
            'isLogged' => $this->context->customer->isLogged()
        ));
        $this->setTemplate($dir_templates . 'order-opc.tpl');
    }

    protected function _getCarrierList()
    {
        $result = parent::_getCarrierList();
        if (isset($result['carrier_block']) && ! empty($result['carrier_block'])) {
            $dir_templates = _PS_MODULE_DIR_ . '/easycheckout/views/templates/front/';
            if (version_compare(_PS_VERSION_, '1.6', '<')){
                $dir_templates = _PS_MODULE_DIR_ . '/easycheckout/views/templates/front15/';
            }            
            $result['carrier_block'] = $this->context->smarty->fetch($dir_templates . 'order-carrier.tpl');
        }
        return $result;
    }

    /**
     * Sobreescribe el metodo del padre para pintar los metodos de pago sin estar logado
     *
     * @return string|unknown
     */
    protected function _getPaymentMethods()
    {
        if (! $this->isLogged) {
            $this->error[] = Tools::displayError('Please sign in to see payment methods.');
        }
        if ($this->context->cart->OrderExists()) {
            $this->error[] = Tools::displayError('Error: This order has already been validated.');
        }
        if (! $this->context->cart->id_customer || ! Customer::customerIdExistsStatic($this->context->cart->id_customer) || Customer::isBanned($this->context->cart->id_customer)) {
            $this->error[] = Tools::displayError('Error: No customer.');
        }
        $address_delivery = new Address($this->context->cart->id_address_delivery);
        $address_invoice = ($this->context->cart->id_address_delivery == $this->context->cart->id_address_invoice ? $address_delivery : new Address($this->context->cart->id_address_invoice));
        if (! $this->context->cart->id_address_delivery || ! $this->context->cart->id_address_invoice || ! Validate::isLoadedObject($address_delivery) || ! Validate::isLoadedObject($address_invoice) || $address_invoice->deleted || $address_delivery->deleted) {
            $this->error[] = Tools::displayError('Error: Please select an address.');
        }
        if (count($this->context->cart->getDeliveryOptionList()) == 0 && ! $this->context->cart->isVirtualCart()) {
            if ($this->context->cart->isMultiAddressDelivery()) {
                $this->error[] = Tools::displayError('Error: None of your chosen carriers deliver to some of the addresses you have selected.');
            } else {
                $this->error[] = Tools::displayError('Error: None of your chosen carriers deliver to the address you have selected.');
            }
        }
        if (! $this->context->cart->getDeliveryOption(null, false) && ! $this->context->cart->isVirtualCart()) {
            $this->error[] = Tools::displayError('Error: Please choose a carrier.');
        }
        if (! $this->context->cart->id_currency) {
            $this->error[] = Tools::displayError('Error: No currency has been selected.');
        }
        if (! $this->context->cookie->checkedTOS && Configuration::get('PS_CONDITIONS')) {
            $this->error[] = Tools::displayError('Please accept the Terms of Service.');
        }
        /* If some products have disappear */
        if (is_array($product = $this->context->cart->checkQuantities(true))) {
            $this->error[] = sprintf(Tools::displayError('An item (%s) in your cart is no longer available in this quantity. You cannot proceed with your order until the quantity is adjusted.'), $product['name']);
        }
        
        /* Check minimal amount */
        $currency = Currency::getCurrency((int) $this->context->cart->id_currency);
        
        $minimal_purchase = Tools::convertPrice((float) Configuration::get('PS_PURCHASE_MINIMUM'), $currency);
        if ($this->context->cart->getOrderTotal(false, Cart::ONLY_PRODUCTS) < $minimal_purchase) {
            $this->error[] = sprintf(Tools::displayError('A minimum purchase total of %1s (tax excl.) is required to validate your order, current purchase total is %2s (tax excl.).'), Tools::displayPrice($minimal_purchase, $currency), Tools::displayPrice($this->context->cart->getOrderTotal(false, Cart::ONLY_PRODUCTS), $currency));
        }
        
        /* Bypass payment step if total is 0 */
        if ($this->context->cart->getOrderTotal() <= 0 && $this->context->customer->islogged()) {
            return '<p class="center"><button class="button btn btn-default button-medium" name="confirmOrder" id="confirmOrder" onclick="confirmFreeOrder();" type="submit"> <span>' . Tools::displayError('I confirm my order.') . '</span></button></p>';
        }
        else if($this->context->cart->getOrderTotal() <= 0){
            return '<p class="center pedido-gratuito">'. Tools::displayError('Pedido gratuito, tienes que logarte para finalizarlo.') . '</span></button></p>';
        }
        
        $return = Hook::exec('displayPayment');
        if (! $return) {
            return Tools::displayError('No payment method is available for use at this time. ');
        } else if (! empty($this->error)) {
                $return = $this->cambiarMetodosPago($return);
        }
        //cambia el evento que lanza el formulario de paypal en caso de éxito
	$return = str_replace('<a href="javascript:void(0)" onclick="$(\'#paypal_payment_form\').submit();"',
	'<a href="javascript:$(\'#paypal_payment_form\').submit();return false;" onclick="$(\'#paypal_payment_form\').submit();"',$return);
	
	$return = str_replace('<a href="javascript:void(0)" onclick=""', '<a href="javascript:$(\'#paypal_payment_form\').submit();return false;" onclick="$(\'#paypal_payment_form\').submit();"',$return);
        
        return $return;
    }

    /**
     * Elimina las acciones de formulario para los métodos de pago
     *
     * @param unknown $metodos_pago            
     * @return mixed
     */
    protected function cambiarMetodosPago($metodos_pago)
    {
	$html_error = '';
	foreach($this->error as $error){
		$html_error .= $error;
	}

        $metodos_cambiados = $metodos_pago;
        $metodos_cambiados = str_replace('payment_module', 'payment_module payment_module_error', $metodos_pago);
        $metodos_cambiados = str_replace('id="paypal_process_payment"', 'id="paypal_process_payment_error"', $metodos_pago);
        $metodos_cambiados = preg_replace('/href="[^ ]*"/i', 'href=\'javascript:void(0);\' onclick=\'clickMetodoPagoError();return false;\'  data=\''.$html_error.'\'', $metodos_cambiados);
        $metodos_cambiados = preg_replace('/href=\'[^ ]*\'/i', 'href=\'javascript:void(0);\' onclick=\'clickMetodoPagoError();return false;\'  data=\''.$html_error.'\'', $metodos_cambiados);
        $metodos_cambiados = preg_replace('/onclick="[^ ]*"/i', 'onclick=\'clickMetodoPagoError();return false;\'  data=\''.$html_error.'\'', $metodos_cambiados);
        $metodos_cambiados = preg_replace('/onclick=\'[^ ]*\'/i', 'onclick=\'clickMetodoPagoError();return false;\' data=\''.$html_error.'\'', $metodos_cambiados);
        return $metodos_cambiados;
    }
}
